fbchat-asyncio
==============

.. image:: https://img.shields.io/badge/license-BSD-blue.svg
    :target: https://github.com/tulir/fbchat-asyncio/tree/master/LICENSE
    :alt: License: BSD 3-Clause

.. image:: https://img.shields.io/badge/python-3.6%203.7-blue.svg
    :target: https://pypi.python.org/pypi/fbchat
    :alt: Supported python versions: 3.6, 3.7

This project is a fork of `carpedm20/fbchat <https://github.com/carpedm20/fbchat>`__ to add asyncio
support. Most of the upstream documentation should apply with the necessary ``async``/``await``
statements added.

Go to `Read the Docs <https://fbchat.readthedocs.io>`__ to see the full documentation,
or jump right into the code by viewing the `examples <https://github.com/carpedm20/fbchat/tree/master/examples>`__

Installation:

.. code-block::

    $ pip install fbchat-asyncio

You can also install from source:

.. code-block::

    $ git clone https://github.com/tulir/fbchat-asyncio.git
    $ cd fbchat-asyncio
    $ pip install .


Maintainer
----------

- Tulir Asokan / `@tulir <https://github.com/tulir>`__

Upstream
^^^^^^^^

- Mads Marquart / `@madsmtm <https://github.com/madsmtm>`__
- Taehoon Kim / `@carpedm20 <http://carpedm20.github.io/about/>`__
